# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class Product(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'djstripe_product': 'DjStripeProduct',
        'prices': 'list[DjStripePrice]',
        'deleted': 'datetime',
        'created_dt': 'datetime',
        'updated_dt': 'datetime',
        'sku': 'str',
        'slug': 'str',
        'unit_label': 'str',
        'name': 'str',
        'description': 'str',
        'statement_descriptor': 'str',
        'images': 'list[str]',
        'is_active': 'bool',
        'is_shippable': 'bool',
        'is_preorder': 'bool',
        'is_subscription': 'bool',
        'stripe_price_lookup_key': 'str',
        'stripe_product_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'djstripe_product': 'djstripe_product',
        'prices': 'prices',
        'deleted': 'deleted',
        'created_dt': 'created_dt',
        'updated_dt': 'updated_dt',
        'sku': 'sku',
        'slug': 'slug',
        'unit_label': 'unit_label',
        'name': 'name',
        'description': 'description',
        'statement_descriptor': 'statement_descriptor',
        'images': 'images',
        'is_active': 'is_active',
        'is_shippable': 'is_shippable',
        'is_preorder': 'is_preorder',
        'is_subscription': 'is_subscription',
        'stripe_price_lookup_key': 'stripe_price_lookup_key',
        'stripe_product_id': 'stripe_product_id'
    }

    def __init__(self, id=None, djstripe_product=None, prices=None, deleted=None, created_dt=None, updated_dt=None, sku=None, slug=None, unit_label=None, name=None, description=None, statement_descriptor=None, images=None, is_active=None, is_shippable=None, is_preorder=None, is_subscription=None, stripe_price_lookup_key=None, stripe_product_id=None, local_vars_configuration=None):  # noqa: E501
        """Product - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._djstripe_product = None
        self._prices = None
        self._deleted = None
        self._created_dt = None
        self._updated_dt = None
        self._sku = None
        self._slug = None
        self._unit_label = None
        self._name = None
        self._description = None
        self._statement_descriptor = None
        self._images = None
        self._is_active = None
        self._is_shippable = None
        self._is_preorder = None
        self._is_subscription = None
        self._stripe_price_lookup_key = None
        self._stripe_product_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.djstripe_product = djstripe_product
        self.prices = prices
        self.deleted = deleted
        self.created_dt = created_dt
        self.updated_dt = updated_dt
        self.sku = sku
        self.slug = slug
        self.unit_label = unit_label
        self.name = name
        self.description = description
        self.statement_descriptor = statement_descriptor
        if images is not None:
            self.images = images
        if is_active is not None:
            self.is_active = is_active
        self.is_shippable = is_shippable
        self.is_preorder = is_preorder
        self.is_subscription = is_subscription
        self.stripe_price_lookup_key = stripe_price_lookup_key
        self.stripe_product_id = stripe_product_id

    @property
    def id(self):
        """Gets the id of this Product.  # noqa: E501


        :return: The id of this Product.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Product.


        :param id: The id of this Product.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def djstripe_product(self):
        """Gets the djstripe_product of this Product.  # noqa: E501


        :return: The djstripe_product of this Product.  # noqa: E501
        :rtype: DjStripeProduct
        """
        return self._djstripe_product

    @djstripe_product.setter
    def djstripe_product(self, djstripe_product):
        """Sets the djstripe_product of this Product.


        :param djstripe_product: The djstripe_product of this Product.  # noqa: E501
        :type djstripe_product: DjStripeProduct
        """
        if self.local_vars_configuration.client_side_validation and djstripe_product is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_product`, must not be `None`")  # noqa: E501

        self._djstripe_product = djstripe_product

    @property
    def prices(self):
        """Gets the prices of this Product.  # noqa: E501


        :return: The prices of this Product.  # noqa: E501
        :rtype: list[DjStripePrice]
        """
        return self._prices

    @prices.setter
    def prices(self, prices):
        """Sets the prices of this Product.


        :param prices: The prices of this Product.  # noqa: E501
        :type prices: list[DjStripePrice]
        """
        if self.local_vars_configuration.client_side_validation and prices is None:  # noqa: E501
            raise ValueError("Invalid value for `prices`, must not be `None`")  # noqa: E501

        self._prices = prices

    @property
    def deleted(self):
        """Gets the deleted of this Product.  # noqa: E501


        :return: The deleted of this Product.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this Product.


        :param deleted: The deleted of this Product.  # noqa: E501
        :type deleted: datetime
        """
        if self.local_vars_configuration.client_side_validation and deleted is None:  # noqa: E501
            raise ValueError("Invalid value for `deleted`, must not be `None`")  # noqa: E501

        self._deleted = deleted

    @property
    def created_dt(self):
        """Gets the created_dt of this Product.  # noqa: E501


        :return: The created_dt of this Product.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this Product.


        :param created_dt: The created_dt of this Product.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def updated_dt(self):
        """Gets the updated_dt of this Product.  # noqa: E501


        :return: The updated_dt of this Product.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this Product.


        :param updated_dt: The updated_dt of this Product.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def sku(self):
        """Gets the sku of this Product.  # noqa: E501


        :return: The sku of this Product.  # noqa: E501
        :rtype: str
        """
        return self._sku

    @sku.setter
    def sku(self, sku):
        """Sets the sku of this Product.


        :param sku: The sku of this Product.  # noqa: E501
        :type sku: str
        """
        if self.local_vars_configuration.client_side_validation and sku is None:  # noqa: E501
            raise ValueError("Invalid value for `sku`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                sku is not None and len(sku) > 255):
            raise ValueError("Invalid value for `sku`, length must be less than or equal to `255`")  # noqa: E501

        self._sku = sku

    @property
    def slug(self):
        """Gets the slug of this Product.  # noqa: E501


        :return: The slug of this Product.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this Product.


        :param slug: The slug of this Product.  # noqa: E501
        :type slug: str
        """
        if self.local_vars_configuration.client_side_validation and slug is None:  # noqa: E501
            raise ValueError("Invalid value for `slug`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                slug is not None and len(slug) > 64):
            raise ValueError("Invalid value for `slug`, length must be less than or equal to `64`")  # noqa: E501

        self._slug = slug

    @property
    def unit_label(self):
        """Gets the unit_label of this Product.  # noqa: E501


        :return: The unit_label of this Product.  # noqa: E501
        :rtype: str
        """
        return self._unit_label

    @unit_label.setter
    def unit_label(self, unit_label):
        """Sets the unit_label of this Product.


        :param unit_label: The unit_label of this Product.  # noqa: E501
        :type unit_label: str
        """
        if self.local_vars_configuration.client_side_validation and unit_label is None:  # noqa: E501
            raise ValueError("Invalid value for `unit_label`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                unit_label is not None and len(unit_label) > 255):
            raise ValueError("Invalid value for `unit_label`, length must be less than or equal to `255`")  # noqa: E501

        self._unit_label = unit_label

    @property
    def name(self):
        """Gets the name of this Product.  # noqa: E501


        :return: The name of this Product.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Product.


        :param name: The name of this Product.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Product.  # noqa: E501


        :return: The description of this Product.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Product.


        :param description: The description of this Product.  # noqa: E501
        :type description: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 255):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `255`")  # noqa: E501

        self._description = description

    @property
    def statement_descriptor(self):
        """Gets the statement_descriptor of this Product.  # noqa: E501


        :return: The statement_descriptor of this Product.  # noqa: E501
        :rtype: str
        """
        return self._statement_descriptor

    @statement_descriptor.setter
    def statement_descriptor(self, statement_descriptor):
        """Sets the statement_descriptor of this Product.


        :param statement_descriptor: The statement_descriptor of this Product.  # noqa: E501
        :type statement_descriptor: str
        """
        if self.local_vars_configuration.client_side_validation and statement_descriptor is None:  # noqa: E501
            raise ValueError("Invalid value for `statement_descriptor`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                statement_descriptor is not None and len(statement_descriptor) > 255):
            raise ValueError("Invalid value for `statement_descriptor`, length must be less than or equal to `255`")  # noqa: E501

        self._statement_descriptor = statement_descriptor

    @property
    def images(self):
        """Gets the images of this Product.  # noqa: E501


        :return: The images of this Product.  # noqa: E501
        :rtype: list[str]
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this Product.


        :param images: The images of this Product.  # noqa: E501
        :type images: list[str]
        """

        self._images = images

    @property
    def is_active(self):
        """Gets the is_active of this Product.  # noqa: E501


        :return: The is_active of this Product.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this Product.


        :param is_active: The is_active of this Product.  # noqa: E501
        :type is_active: bool
        """

        self._is_active = is_active

    @property
    def is_shippable(self):
        """Gets the is_shippable of this Product.  # noqa: E501


        :return: The is_shippable of this Product.  # noqa: E501
        :rtype: bool
        """
        return self._is_shippable

    @is_shippable.setter
    def is_shippable(self, is_shippable):
        """Sets the is_shippable of this Product.


        :param is_shippable: The is_shippable of this Product.  # noqa: E501
        :type is_shippable: bool
        """
        if self.local_vars_configuration.client_side_validation and is_shippable is None:  # noqa: E501
            raise ValueError("Invalid value for `is_shippable`, must not be `None`")  # noqa: E501

        self._is_shippable = is_shippable

    @property
    def is_preorder(self):
        """Gets the is_preorder of this Product.  # noqa: E501


        :return: The is_preorder of this Product.  # noqa: E501
        :rtype: bool
        """
        return self._is_preorder

    @is_preorder.setter
    def is_preorder(self, is_preorder):
        """Sets the is_preorder of this Product.


        :param is_preorder: The is_preorder of this Product.  # noqa: E501
        :type is_preorder: bool
        """
        if self.local_vars_configuration.client_side_validation and is_preorder is None:  # noqa: E501
            raise ValueError("Invalid value for `is_preorder`, must not be `None`")  # noqa: E501

        self._is_preorder = is_preorder

    @property
    def is_subscription(self):
        """Gets the is_subscription of this Product.  # noqa: E501


        :return: The is_subscription of this Product.  # noqa: E501
        :rtype: bool
        """
        return self._is_subscription

    @is_subscription.setter
    def is_subscription(self, is_subscription):
        """Sets the is_subscription of this Product.


        :param is_subscription: The is_subscription of this Product.  # noqa: E501
        :type is_subscription: bool
        """
        if self.local_vars_configuration.client_side_validation and is_subscription is None:  # noqa: E501
            raise ValueError("Invalid value for `is_subscription`, must not be `None`")  # noqa: E501

        self._is_subscription = is_subscription

    @property
    def stripe_price_lookup_key(self):
        """Gets the stripe_price_lookup_key of this Product.  # noqa: E501


        :return: The stripe_price_lookup_key of this Product.  # noqa: E501
        :rtype: str
        """
        return self._stripe_price_lookup_key

    @stripe_price_lookup_key.setter
    def stripe_price_lookup_key(self, stripe_price_lookup_key):
        """Sets the stripe_price_lookup_key of this Product.


        :param stripe_price_lookup_key: The stripe_price_lookup_key of this Product.  # noqa: E501
        :type stripe_price_lookup_key: str
        """
        if (self.local_vars_configuration.client_side_validation and
                stripe_price_lookup_key is not None and len(stripe_price_lookup_key) > 255):
            raise ValueError("Invalid value for `stripe_price_lookup_key`, length must be less than or equal to `255`")  # noqa: E501

        self._stripe_price_lookup_key = stripe_price_lookup_key

    @property
    def stripe_product_id(self):
        """Gets the stripe_product_id of this Product.  # noqa: E501


        :return: The stripe_product_id of this Product.  # noqa: E501
        :rtype: str
        """
        return self._stripe_product_id

    @stripe_product_id.setter
    def stripe_product_id(self, stripe_product_id):
        """Sets the stripe_product_id of this Product.


        :param stripe_product_id: The stripe_product_id of this Product.  # noqa: E501
        :type stripe_product_id: str
        """
        if (self.local_vars_configuration.client_side_validation and
                stripe_product_id is not None and len(stripe_product_id) > 255):
            raise ValueError("Invalid value for `stripe_product_id`, length must be less than or equal to `255`")  # noqa: E501

        self._stripe_product_id = stripe_product_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Product):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Product):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class SystemInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'bootfs_available': 'int',
        'bootfs_available_pretty': 'str',
        'bootfs_used_pretty': 'str',
        'bootfs_size_pretty': 'str',
        'datafs_available': 'int',
        'datafs_available_pretty': 'str',
        'datafs_used_pretty': 'str',
        'datafs_size_pretty': 'str',
        'rootfs_available': 'int',
        'rootfs_available_pretty': 'str',
        'rootfs_size_pretty': 'str',
        'rootfs_used_pretty': 'str',
        'created_dt': 'datetime',
        'updated_dt': 'datetime',
        'machine_id': 'str',
        'revision': 'str',
        'model': 'str',
        'serial': 'str',
        'cores': 'int',
        'ram': 'int',
        'os_version_id': 'str',
        'os_build_id': 'datetime',
        'os_variant_id': 'str',
        'os_release_json': 'dict(str, object)',
        'uptime': 'int',
        'rootfs_size': 'int',
        'rootfs_used': 'int',
        'bootfs_size': 'int',
        'bootfs_used': 'int',
        'datafs_size': 'int',
        'datafs_used': 'int',
        'pi': 'int'
    }

    attribute_map = {
        'id': 'id',
        'bootfs_available': 'bootfs_available',
        'bootfs_available_pretty': 'bootfs_available_pretty',
        'bootfs_used_pretty': 'bootfs_used_pretty',
        'bootfs_size_pretty': 'bootfs_size_pretty',
        'datafs_available': 'datafs_available',
        'datafs_available_pretty': 'datafs_available_pretty',
        'datafs_used_pretty': 'datafs_used_pretty',
        'datafs_size_pretty': 'datafs_size_pretty',
        'rootfs_available': 'rootfs_available',
        'rootfs_available_pretty': 'rootfs_available_pretty',
        'rootfs_size_pretty': 'rootfs_size_pretty',
        'rootfs_used_pretty': 'rootfs_used_pretty',
        'created_dt': 'created_dt',
        'updated_dt': 'updated_dt',
        'machine_id': 'machine_id',
        'revision': 'revision',
        'model': 'model',
        'serial': 'serial',
        'cores': 'cores',
        'ram': 'ram',
        'os_version_id': 'os_version_id',
        'os_build_id': 'os_build_id',
        'os_variant_id': 'os_variant_id',
        'os_release_json': 'os_release_json',
        'uptime': 'uptime',
        'rootfs_size': 'rootfs_size',
        'rootfs_used': 'rootfs_used',
        'bootfs_size': 'bootfs_size',
        'bootfs_used': 'bootfs_used',
        'datafs_size': 'datafs_size',
        'datafs_used': 'datafs_used',
        'pi': 'pi'
    }

    def __init__(self, id=None, bootfs_available=None, bootfs_available_pretty=None, bootfs_used_pretty=None, bootfs_size_pretty=None, datafs_available=None, datafs_available_pretty=None, datafs_used_pretty=None, datafs_size_pretty=None, rootfs_available=None, rootfs_available_pretty=None, rootfs_size_pretty=None, rootfs_used_pretty=None, created_dt=None, updated_dt=None, machine_id=None, revision=None, model=None, serial=None, cores=None, ram=None, os_version_id=None, os_build_id=None, os_variant_id=None, os_release_json=None, uptime=None, rootfs_size=None, rootfs_used=None, bootfs_size=None, bootfs_used=None, datafs_size=None, datafs_used=None, pi=None, local_vars_configuration=None):  # noqa: E501
        """SystemInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._bootfs_available = None
        self._bootfs_available_pretty = None
        self._bootfs_used_pretty = None
        self._bootfs_size_pretty = None
        self._datafs_available = None
        self._datafs_available_pretty = None
        self._datafs_used_pretty = None
        self._datafs_size_pretty = None
        self._rootfs_available = None
        self._rootfs_available_pretty = None
        self._rootfs_size_pretty = None
        self._rootfs_used_pretty = None
        self._created_dt = None
        self._updated_dt = None
        self._machine_id = None
        self._revision = None
        self._model = None
        self._serial = None
        self._cores = None
        self._ram = None
        self._os_version_id = None
        self._os_build_id = None
        self._os_variant_id = None
        self._os_release_json = None
        self._uptime = None
        self._rootfs_size = None
        self._rootfs_used = None
        self._bootfs_size = None
        self._bootfs_used = None
        self._datafs_size = None
        self._datafs_used = None
        self._pi = None
        self.discriminator = None

        self.id = id
        self.bootfs_available = bootfs_available
        self.bootfs_available_pretty = bootfs_available_pretty
        self.bootfs_used_pretty = bootfs_used_pretty
        self.bootfs_size_pretty = bootfs_size_pretty
        self.datafs_available = datafs_available
        self.datafs_available_pretty = datafs_available_pretty
        self.datafs_used_pretty = datafs_used_pretty
        self.datafs_size_pretty = datafs_size_pretty
        self.rootfs_available = rootfs_available
        self.rootfs_available_pretty = rootfs_available_pretty
        self.rootfs_size_pretty = rootfs_size_pretty
        self.rootfs_used_pretty = rootfs_used_pretty
        self.created_dt = created_dt
        self.updated_dt = updated_dt
        self.machine_id = machine_id
        self.revision = revision
        self.model = model
        self.serial = serial
        self.cores = cores
        self.ram = ram
        self.os_version_id = os_version_id
        self.os_build_id = os_build_id
        self.os_variant_id = os_variant_id
        if os_release_json is not None:
            self.os_release_json = os_release_json
        self.uptime = uptime
        self.rootfs_size = rootfs_size
        self.rootfs_used = rootfs_used
        self.bootfs_size = bootfs_size
        self.bootfs_used = bootfs_used
        self.datafs_size = datafs_size
        self.datafs_used = datafs_used
        self.pi = pi

    @property
    def id(self):
        """Gets the id of this SystemInfo.  # noqa: E501


        :return: The id of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SystemInfo.


        :param id: The id of this SystemInfo.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def bootfs_available(self):
        """Gets the bootfs_available of this SystemInfo.  # noqa: E501


        :return: The bootfs_available of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._bootfs_available

    @bootfs_available.setter
    def bootfs_available(self, bootfs_available):
        """Sets the bootfs_available of this SystemInfo.


        :param bootfs_available: The bootfs_available of this SystemInfo.  # noqa: E501
        :type bootfs_available: int
        """
        if self.local_vars_configuration.client_side_validation and bootfs_available is None:  # noqa: E501
            raise ValueError("Invalid value for `bootfs_available`, must not be `None`")  # noqa: E501

        self._bootfs_available = bootfs_available

    @property
    def bootfs_available_pretty(self):
        """Gets the bootfs_available_pretty of this SystemInfo.  # noqa: E501


        :return: The bootfs_available_pretty of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._bootfs_available_pretty

    @bootfs_available_pretty.setter
    def bootfs_available_pretty(self, bootfs_available_pretty):
        """Sets the bootfs_available_pretty of this SystemInfo.


        :param bootfs_available_pretty: The bootfs_available_pretty of this SystemInfo.  # noqa: E501
        :type bootfs_available_pretty: str
        """
        if self.local_vars_configuration.client_side_validation and bootfs_available_pretty is None:  # noqa: E501
            raise ValueError("Invalid value for `bootfs_available_pretty`, must not be `None`")  # noqa: E501

        self._bootfs_available_pretty = bootfs_available_pretty

    @property
    def bootfs_used_pretty(self):
        """Gets the bootfs_used_pretty of this SystemInfo.  # noqa: E501


        :return: The bootfs_used_pretty of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._bootfs_used_pretty

    @bootfs_used_pretty.setter
    def bootfs_used_pretty(self, bootfs_used_pretty):
        """Sets the bootfs_used_pretty of this SystemInfo.


        :param bootfs_used_pretty: The bootfs_used_pretty of this SystemInfo.  # noqa: E501
        :type bootfs_used_pretty: str
        """
        if self.local_vars_configuration.client_side_validation and bootfs_used_pretty is None:  # noqa: E501
            raise ValueError("Invalid value for `bootfs_used_pretty`, must not be `None`")  # noqa: E501

        self._bootfs_used_pretty = bootfs_used_pretty

    @property
    def bootfs_size_pretty(self):
        """Gets the bootfs_size_pretty of this SystemInfo.  # noqa: E501


        :return: The bootfs_size_pretty of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._bootfs_size_pretty

    @bootfs_size_pretty.setter
    def bootfs_size_pretty(self, bootfs_size_pretty):
        """Sets the bootfs_size_pretty of this SystemInfo.


        :param bootfs_size_pretty: The bootfs_size_pretty of this SystemInfo.  # noqa: E501
        :type bootfs_size_pretty: str
        """
        if self.local_vars_configuration.client_side_validation and bootfs_size_pretty is None:  # noqa: E501
            raise ValueError("Invalid value for `bootfs_size_pretty`, must not be `None`")  # noqa: E501

        self._bootfs_size_pretty = bootfs_size_pretty

    @property
    def datafs_available(self):
        """Gets the datafs_available of this SystemInfo.  # noqa: E501


        :return: The datafs_available of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._datafs_available

    @datafs_available.setter
    def datafs_available(self, datafs_available):
        """Sets the datafs_available of this SystemInfo.


        :param datafs_available: The datafs_available of this SystemInfo.  # noqa: E501
        :type datafs_available: int
        """
        if self.local_vars_configuration.client_side_validation and datafs_available is None:  # noqa: E501
            raise ValueError("Invalid value for `datafs_available`, must not be `None`")  # noqa: E501

        self._datafs_available = datafs_available

    @property
    def datafs_available_pretty(self):
        """Gets the datafs_available_pretty of this SystemInfo.  # noqa: E501


        :return: The datafs_available_pretty of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._datafs_available_pretty

    @datafs_available_pretty.setter
    def datafs_available_pretty(self, datafs_available_pretty):
        """Sets the datafs_available_pretty of this SystemInfo.


        :param datafs_available_pretty: The datafs_available_pretty of this SystemInfo.  # noqa: E501
        :type datafs_available_pretty: str
        """
        if self.local_vars_configuration.client_side_validation and datafs_available_pretty is None:  # noqa: E501
            raise ValueError("Invalid value for `datafs_available_pretty`, must not be `None`")  # noqa: E501

        self._datafs_available_pretty = datafs_available_pretty

    @property
    def datafs_used_pretty(self):
        """Gets the datafs_used_pretty of this SystemInfo.  # noqa: E501


        :return: The datafs_used_pretty of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._datafs_used_pretty

    @datafs_used_pretty.setter
    def datafs_used_pretty(self, datafs_used_pretty):
        """Sets the datafs_used_pretty of this SystemInfo.


        :param datafs_used_pretty: The datafs_used_pretty of this SystemInfo.  # noqa: E501
        :type datafs_used_pretty: str
        """
        if self.local_vars_configuration.client_side_validation and datafs_used_pretty is None:  # noqa: E501
            raise ValueError("Invalid value for `datafs_used_pretty`, must not be `None`")  # noqa: E501

        self._datafs_used_pretty = datafs_used_pretty

    @property
    def datafs_size_pretty(self):
        """Gets the datafs_size_pretty of this SystemInfo.  # noqa: E501


        :return: The datafs_size_pretty of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._datafs_size_pretty

    @datafs_size_pretty.setter
    def datafs_size_pretty(self, datafs_size_pretty):
        """Sets the datafs_size_pretty of this SystemInfo.


        :param datafs_size_pretty: The datafs_size_pretty of this SystemInfo.  # noqa: E501
        :type datafs_size_pretty: str
        """
        if self.local_vars_configuration.client_side_validation and datafs_size_pretty is None:  # noqa: E501
            raise ValueError("Invalid value for `datafs_size_pretty`, must not be `None`")  # noqa: E501

        self._datafs_size_pretty = datafs_size_pretty

    @property
    def rootfs_available(self):
        """Gets the rootfs_available of this SystemInfo.  # noqa: E501


        :return: The rootfs_available of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._rootfs_available

    @rootfs_available.setter
    def rootfs_available(self, rootfs_available):
        """Sets the rootfs_available of this SystemInfo.


        :param rootfs_available: The rootfs_available of this SystemInfo.  # noqa: E501
        :type rootfs_available: int
        """
        if self.local_vars_configuration.client_side_validation and rootfs_available is None:  # noqa: E501
            raise ValueError("Invalid value for `rootfs_available`, must not be `None`")  # noqa: E501

        self._rootfs_available = rootfs_available

    @property
    def rootfs_available_pretty(self):
        """Gets the rootfs_available_pretty of this SystemInfo.  # noqa: E501


        :return: The rootfs_available_pretty of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._rootfs_available_pretty

    @rootfs_available_pretty.setter
    def rootfs_available_pretty(self, rootfs_available_pretty):
        """Sets the rootfs_available_pretty of this SystemInfo.


        :param rootfs_available_pretty: The rootfs_available_pretty of this SystemInfo.  # noqa: E501
        :type rootfs_available_pretty: str
        """
        if self.local_vars_configuration.client_side_validation and rootfs_available_pretty is None:  # noqa: E501
            raise ValueError("Invalid value for `rootfs_available_pretty`, must not be `None`")  # noqa: E501

        self._rootfs_available_pretty = rootfs_available_pretty

    @property
    def rootfs_size_pretty(self):
        """Gets the rootfs_size_pretty of this SystemInfo.  # noqa: E501


        :return: The rootfs_size_pretty of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._rootfs_size_pretty

    @rootfs_size_pretty.setter
    def rootfs_size_pretty(self, rootfs_size_pretty):
        """Sets the rootfs_size_pretty of this SystemInfo.


        :param rootfs_size_pretty: The rootfs_size_pretty of this SystemInfo.  # noqa: E501
        :type rootfs_size_pretty: str
        """
        if self.local_vars_configuration.client_side_validation and rootfs_size_pretty is None:  # noqa: E501
            raise ValueError("Invalid value for `rootfs_size_pretty`, must not be `None`")  # noqa: E501

        self._rootfs_size_pretty = rootfs_size_pretty

    @property
    def rootfs_used_pretty(self):
        """Gets the rootfs_used_pretty of this SystemInfo.  # noqa: E501


        :return: The rootfs_used_pretty of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._rootfs_used_pretty

    @rootfs_used_pretty.setter
    def rootfs_used_pretty(self, rootfs_used_pretty):
        """Sets the rootfs_used_pretty of this SystemInfo.


        :param rootfs_used_pretty: The rootfs_used_pretty of this SystemInfo.  # noqa: E501
        :type rootfs_used_pretty: str
        """
        if self.local_vars_configuration.client_side_validation and rootfs_used_pretty is None:  # noqa: E501
            raise ValueError("Invalid value for `rootfs_used_pretty`, must not be `None`")  # noqa: E501

        self._rootfs_used_pretty = rootfs_used_pretty

    @property
    def created_dt(self):
        """Gets the created_dt of this SystemInfo.  # noqa: E501


        :return: The created_dt of this SystemInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this SystemInfo.


        :param created_dt: The created_dt of this SystemInfo.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def updated_dt(self):
        """Gets the updated_dt of this SystemInfo.  # noqa: E501


        :return: The updated_dt of this SystemInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this SystemInfo.


        :param updated_dt: The updated_dt of this SystemInfo.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def machine_id(self):
        """Gets the machine_id of this SystemInfo.  # noqa: E501

        Populated from /etc/machine-id  # noqa: E501

        :return: The machine_id of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._machine_id

    @machine_id.setter
    def machine_id(self, machine_id):
        """Sets the machine_id of this SystemInfo.

        Populated from /etc/machine-id  # noqa: E501

        :param machine_id: The machine_id of this SystemInfo.  # noqa: E501
        :type machine_id: str
        """
        if self.local_vars_configuration.client_side_validation and machine_id is None:  # noqa: E501
            raise ValueError("Invalid value for `machine_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                machine_id is not None and len(machine_id) > 255):
            raise ValueError("Invalid value for `machine_id`, length must be less than or equal to `255`")  # noqa: E501

        self._machine_id = machine_id

    @property
    def revision(self):
        """Gets the revision of this SystemInfo.  # noqa: E501

        Populated from /proc/cpuinfo REVISION  # noqa: E501

        :return: The revision of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this SystemInfo.

        Populated from /proc/cpuinfo REVISION  # noqa: E501

        :param revision: The revision of this SystemInfo.  # noqa: E501
        :type revision: str
        """
        if self.local_vars_configuration.client_side_validation and revision is None:  # noqa: E501
            raise ValueError("Invalid value for `revision`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                revision is not None and len(revision) > 255):
            raise ValueError("Invalid value for `revision`, length must be less than or equal to `255`")  # noqa: E501

        self._revision = revision

    @property
    def model(self):
        """Gets the model of this SystemInfo.  # noqa: E501

        Populated from /proc/cpuinfo MODEL  # noqa: E501

        :return: The model of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this SystemInfo.

        Populated from /proc/cpuinfo MODEL  # noqa: E501

        :param model: The model of this SystemInfo.  # noqa: E501
        :type model: str
        """
        if self.local_vars_configuration.client_side_validation and model is None:  # noqa: E501
            raise ValueError("Invalid value for `model`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                model is not None and len(model) > 255):
            raise ValueError("Invalid value for `model`, length must be less than or equal to `255`")  # noqa: E501

        self._model = model

    @property
    def serial(self):
        """Gets the serial of this SystemInfo.  # noqa: E501

        Populated from /proc/cpuinfo SERIAL  # noqa: E501

        :return: The serial of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._serial

    @serial.setter
    def serial(self, serial):
        """Sets the serial of this SystemInfo.

        Populated from /proc/cpuinfo SERIAL  # noqa: E501

        :param serial: The serial of this SystemInfo.  # noqa: E501
        :type serial: str
        """
        if self.local_vars_configuration.client_side_validation and serial is None:  # noqa: E501
            raise ValueError("Invalid value for `serial`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                serial is not None and len(serial) > 255):
            raise ValueError("Invalid value for `serial`, length must be less than or equal to `255`")  # noqa: E501

        self._serial = serial

    @property
    def cores(self):
        """Gets the cores of this SystemInfo.  # noqa: E501


        :return: The cores of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._cores

    @cores.setter
    def cores(self, cores):
        """Sets the cores of this SystemInfo.


        :param cores: The cores of this SystemInfo.  # noqa: E501
        :type cores: int
        """
        if self.local_vars_configuration.client_side_validation and cores is None:  # noqa: E501
            raise ValueError("Invalid value for `cores`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cores is not None and cores > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `cores`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cores is not None and cores < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `cores`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._cores = cores

    @property
    def ram(self):
        """Gets the ram of this SystemInfo.  # noqa: E501


        :return: The ram of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._ram

    @ram.setter
    def ram(self, ram):
        """Sets the ram of this SystemInfo.


        :param ram: The ram of this SystemInfo.  # noqa: E501
        :type ram: int
        """
        if self.local_vars_configuration.client_side_validation and ram is None:  # noqa: E501
            raise ValueError("Invalid value for `ram`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                ram is not None and ram > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `ram`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                ram is not None and ram < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `ram`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._ram = ram

    @property
    def os_version_id(self):
        """Gets the os_version_id of this SystemInfo.  # noqa: E501

        PrintNanny OS VERSION_ID from /etc/os-release  # noqa: E501

        :return: The os_version_id of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._os_version_id

    @os_version_id.setter
    def os_version_id(self, os_version_id):
        """Sets the os_version_id of this SystemInfo.

        PrintNanny OS VERSION_ID from /etc/os-release  # noqa: E501

        :param os_version_id: The os_version_id of this SystemInfo.  # noqa: E501
        :type os_version_id: str
        """
        if self.local_vars_configuration.client_side_validation and os_version_id is None:  # noqa: E501
            raise ValueError("Invalid value for `os_version_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                os_version_id is not None and len(os_version_id) > 255):
            raise ValueError("Invalid value for `os_version_id`, length must be less than or equal to `255`")  # noqa: E501

        self._os_version_id = os_version_id

    @property
    def os_build_id(self):
        """Gets the os_build_id of this SystemInfo.  # noqa: E501

        PrintNanny OS BUILD_ID from /etc/os-release  # noqa: E501

        :return: The os_build_id of this SystemInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._os_build_id

    @os_build_id.setter
    def os_build_id(self, os_build_id):
        """Sets the os_build_id of this SystemInfo.

        PrintNanny OS BUILD_ID from /etc/os-release  # noqa: E501

        :param os_build_id: The os_build_id of this SystemInfo.  # noqa: E501
        :type os_build_id: datetime
        """
        if self.local_vars_configuration.client_side_validation and os_build_id is None:  # noqa: E501
            raise ValueError("Invalid value for `os_build_id`, must not be `None`")  # noqa: E501

        self._os_build_id = os_build_id

    @property
    def os_variant_id(self):
        """Gets the os_variant_id of this SystemInfo.  # noqa: E501

        PrintNanny OS VARIANT_ID from /etc/os-release  # noqa: E501

        :return: The os_variant_id of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._os_variant_id

    @os_variant_id.setter
    def os_variant_id(self, os_variant_id):
        """Sets the os_variant_id of this SystemInfo.

        PrintNanny OS VARIANT_ID from /etc/os-release  # noqa: E501

        :param os_variant_id: The os_variant_id of this SystemInfo.  # noqa: E501
        :type os_variant_id: str
        """
        if self.local_vars_configuration.client_side_validation and os_variant_id is None:  # noqa: E501
            raise ValueError("Invalid value for `os_variant_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                os_variant_id is not None and len(os_variant_id) > 255):
            raise ValueError("Invalid value for `os_variant_id`, length must be less than or equal to `255`")  # noqa: E501

        self._os_variant_id = os_variant_id

    @property
    def os_release_json(self):
        """Gets the os_release_json of this SystemInfo.  # noqa: E501

        Full contents of /etc/os-release in key:value format  # noqa: E501

        :return: The os_release_json of this SystemInfo.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._os_release_json

    @os_release_json.setter
    def os_release_json(self, os_release_json):
        """Sets the os_release_json of this SystemInfo.

        Full contents of /etc/os-release in key:value format  # noqa: E501

        :param os_release_json: The os_release_json of this SystemInfo.  # noqa: E501
        :type os_release_json: dict(str, object)
        """

        self._os_release_json = os_release_json

    @property
    def uptime(self):
        """Gets the uptime of this SystemInfo.  # noqa: E501

        system uptime (in seconds)  # noqa: E501

        :return: The uptime of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._uptime

    @uptime.setter
    def uptime(self, uptime):
        """Sets the uptime of this SystemInfo.

        system uptime (in seconds)  # noqa: E501

        :param uptime: The uptime of this SystemInfo.  # noqa: E501
        :type uptime: int
        """
        if self.local_vars_configuration.client_side_validation and uptime is None:  # noqa: E501
            raise ValueError("Invalid value for `uptime`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                uptime is not None and uptime > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `uptime`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                uptime is not None and uptime < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `uptime`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._uptime = uptime

    @property
    def rootfs_size(self):
        """Gets the rootfs_size of this SystemInfo.  # noqa: E501

        Size of /dev/root filesystem in bytes  # noqa: E501

        :return: The rootfs_size of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._rootfs_size

    @rootfs_size.setter
    def rootfs_size(self, rootfs_size):
        """Sets the rootfs_size of this SystemInfo.

        Size of /dev/root filesystem in bytes  # noqa: E501

        :param rootfs_size: The rootfs_size of this SystemInfo.  # noqa: E501
        :type rootfs_size: int
        """
        if self.local_vars_configuration.client_side_validation and rootfs_size is None:  # noqa: E501
            raise ValueError("Invalid value for `rootfs_size`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                rootfs_size is not None and rootfs_size > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `rootfs_size`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                rootfs_size is not None and rootfs_size < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `rootfs_size`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._rootfs_size = rootfs_size

    @property
    def rootfs_used(self):
        """Gets the rootfs_used of this SystemInfo.  # noqa: E501

        Space used in /dev/root filesystem in bytes  # noqa: E501

        :return: The rootfs_used of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._rootfs_used

    @rootfs_used.setter
    def rootfs_used(self, rootfs_used):
        """Sets the rootfs_used of this SystemInfo.

        Space used in /dev/root filesystem in bytes  # noqa: E501

        :param rootfs_used: The rootfs_used of this SystemInfo.  # noqa: E501
        :type rootfs_used: int
        """
        if self.local_vars_configuration.client_side_validation and rootfs_used is None:  # noqa: E501
            raise ValueError("Invalid value for `rootfs_used`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                rootfs_used is not None and rootfs_used > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `rootfs_used`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                rootfs_used is not None and rootfs_used < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `rootfs_used`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._rootfs_used = rootfs_used

    @property
    def bootfs_size(self):
        """Gets the bootfs_size of this SystemInfo.  # noqa: E501

        Size of /dev/mmcblk0p1 filesystem in bytes  # noqa: E501

        :return: The bootfs_size of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._bootfs_size

    @bootfs_size.setter
    def bootfs_size(self, bootfs_size):
        """Sets the bootfs_size of this SystemInfo.

        Size of /dev/mmcblk0p1 filesystem in bytes  # noqa: E501

        :param bootfs_size: The bootfs_size of this SystemInfo.  # noqa: E501
        :type bootfs_size: int
        """
        if self.local_vars_configuration.client_side_validation and bootfs_size is None:  # noqa: E501
            raise ValueError("Invalid value for `bootfs_size`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bootfs_size is not None and bootfs_size > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `bootfs_size`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bootfs_size is not None and bootfs_size < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `bootfs_size`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._bootfs_size = bootfs_size

    @property
    def bootfs_used(self):
        """Gets the bootfs_used of this SystemInfo.  # noqa: E501

        Space used in /dev/mmcblk0p1 filesystem in bytes  # noqa: E501

        :return: The bootfs_used of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._bootfs_used

    @bootfs_used.setter
    def bootfs_used(self, bootfs_used):
        """Sets the bootfs_used of this SystemInfo.

        Space used in /dev/mmcblk0p1 filesystem in bytes  # noqa: E501

        :param bootfs_used: The bootfs_used of this SystemInfo.  # noqa: E501
        :type bootfs_used: int
        """
        if self.local_vars_configuration.client_side_validation and bootfs_used is None:  # noqa: E501
            raise ValueError("Invalid value for `bootfs_used`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bootfs_used is not None and bootfs_used > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `bootfs_used`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bootfs_used is not None and bootfs_used < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `bootfs_used`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._bootfs_used = bootfs_used

    @property
    def datafs_size(self):
        """Gets the datafs_size of this SystemInfo.  # noqa: E501

        Size of /dev/mmcblk0p4 filesystem in bytes  # noqa: E501

        :return: The datafs_size of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._datafs_size

    @datafs_size.setter
    def datafs_size(self, datafs_size):
        """Sets the datafs_size of this SystemInfo.

        Size of /dev/mmcblk0p4 filesystem in bytes  # noqa: E501

        :param datafs_size: The datafs_size of this SystemInfo.  # noqa: E501
        :type datafs_size: int
        """
        if self.local_vars_configuration.client_side_validation and datafs_size is None:  # noqa: E501
            raise ValueError("Invalid value for `datafs_size`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                datafs_size is not None and datafs_size > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `datafs_size`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                datafs_size is not None and datafs_size < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `datafs_size`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._datafs_size = datafs_size

    @property
    def datafs_used(self):
        """Gets the datafs_used of this SystemInfo.  # noqa: E501

        Space used in /dev/mmcblk0p4 filesystem in bytes  # noqa: E501

        :return: The datafs_used of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._datafs_used

    @datafs_used.setter
    def datafs_used(self, datafs_used):
        """Sets the datafs_used of this SystemInfo.

        Space used in /dev/mmcblk0p4 filesystem in bytes  # noqa: E501

        :param datafs_used: The datafs_used of this SystemInfo.  # noqa: E501
        :type datafs_used: int
        """
        if self.local_vars_configuration.client_side_validation and datafs_used is None:  # noqa: E501
            raise ValueError("Invalid value for `datafs_used`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                datafs_used is not None and datafs_used > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `datafs_used`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                datafs_used is not None and datafs_used < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `datafs_used`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._datafs_used = datafs_used

    @property
    def pi(self):
        """Gets the pi of this SystemInfo.  # noqa: E501


        :return: The pi of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._pi

    @pi.setter
    def pi(self, pi):
        """Sets the pi of this SystemInfo.


        :param pi: The pi of this SystemInfo.  # noqa: E501
        :type pi: int
        """
        if self.local_vars_configuration.client_side_validation and pi is None:  # noqa: E501
            raise ValueError("Invalid value for `pi`, must not be `None`")  # noqa: E501

        self._pi = pi

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SystemInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.dj_stripe_product import DjStripeProduct  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestDjStripeProduct(unittest.TestCase):
    """DjStripeProduct unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DjStripeProduct
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.dj_stripe_product.DjStripeProduct()  # noqa: E501
        if include_optional :
            return DjStripeProduct(
                djstripe_id = 56, 
                djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                id = '', 
                livemode = True, 
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                metadata = {
                    'key' : null
                    }, 
                description = '', 
                name = '', 
                type = None, 
                active = True, 
                attributes = {
                    'key' : null
                    }, 
                caption = '', 
                deactivate_on = {
                    'key' : null
                    }, 
                images = {
                    'key' : null
                    }, 
                package_dimensions = {
                    'key' : null
                    }, 
                shippable = True, 
                url = '', 
                statement_descriptor = '', 
                unit_label = '', 
                djstripe_owner_account = ''
            )
        else :
            return DjStripeProduct(
                djstripe_id = 56,
                djstripe_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                djstripe_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                name = '',
                type = None,
        )

    def testDjStripeProduct(self):
        """Test DjStripeProduct"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class StripeApiErrorCode(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    ACCOUNT_ALREADY_EXISTS = "account_already_exists"
    ACCOUNT_COUNTRY_INVALID_ADDRESS = "account_country_invalid_address"
    ACCOUNT_INVALID = "account_invalid"
    ACCOUNT_NUMBER_INVALID = "account_number_invalid"
    ALIPAY_UPGRADE_REQUIRED = "alipay_upgrade_required"
    AMOUNT_TOO_LARGE = "amount_too_large"
    AMOUNT_TOO_SMALL = "amount_too_small"
    API_KEY_EXPIRED = "api_key_expired"
    BALANCE_INSUFFICIENT = "balance_insufficient"
    BANK_ACCOUNT_EXISTS = "bank_account_exists"
    BANK_ACCOUNT_UNUSABLE = "bank_account_unusable"
    BANK_ACCOUNT_UNVERIFIED = "bank_account_unverified"
    BITCOIN_UPGRADE_REQUIRED = "bitcoin_upgrade_required"
    CARD_DECLINED = "card_declined"
    CHARGE_ALREADY_CAPTURED = "charge_already_captured"
    CHARGE_ALREADY_REFUNDED = "charge_already_refunded"
    CHARGE_DISPUTED = "charge_disputed"
    CHARGE_EXCEEDS_SOURCE_LIMIT = "charge_exceeds_source_limit"
    CHARGE_EXPIRED_FOR_CAPTURE = "charge_expired_for_capture"
    COUNTRY_UNSUPPORTED = "country_unsupported"
    COUPON_EXPIRED = "coupon_expired"
    CUSTOMER_MAX_SUBSCRIPTIONS = "customer_max_subscriptions"
    EMAIL_INVALID = "email_invalid"
    EXPIRED_CARD = "expired_card"
    IDEMPOTENCY_KEY_IN_USE = "idempotency_key_in_use"
    INCORRECT_ADDRESS = "incorrect_address"
    INCORRECT_CVC = "incorrect_cvc"
    INCORRECT_NUMBER = "incorrect_number"
    INCORRECT_ZIP = "incorrect_zip"
    INSTANT_PAYOUTS_UNSUPPORTED = "instant_payouts_unsupported"
    INVALID_CARD_TYPE = "invalid_card_type"
    INVALID_CHARGE_AMOUNT = "invalid_charge_amount"
    INVALID_CVC = "invalid_cvc"
    INVALID_EXPIRY_MONTH = "invalid_expiry_month"
    INVALID_EXPIRY_YEAR = "invalid_expiry_year"
    INVALID_NUMBER = "invalid_number"
    INVALID_SOURCE_USAGE = "invalid_source_usage"
    INVALID_SWIPE_DATA = "invalid_swipe_data"
    INVOICE_NO_CUSTOMER_LINE_ITEMS = "invoice_no_customer_line_items"
    INVOICE_NO_SUBSCRIPTION_LINE_ITEMS = "invoice_no_subscription_line_items"
    INVOICE_NOT_EDITABLE = "invoice_not_editable"
    INVOICE_UPCOMING_NONE = "invoice_upcoming_none"
    LIVEMODE_MISMATCH = "livemode_mismatch"
    MISSING = "missing"
    NOT_ALLOWED_ON_STANDARD_ACCOUNT = "not_allowed_on_standard_account"
    ORDER_CREATION_FAILED = "order_creation_failed"
    ORDER_REQUIRED_SETTINGS = "order_required_settings"
    ORDER_STATUS_INVALID = "order_status_invalid"
    ORDER_UPSTREAM_TIMEOUT = "order_upstream_timeout"
    OUT_OF_INVENTORY = "out_of_inventory"
    PARAMETER_INVALID_EMPTY = "parameter_invalid_empty"
    PARAMETER_INVALID_INTEGER = "parameter_invalid_integer"
    PARAMETER_INVALID_STRING_BLANK = "parameter_invalid_string_blank"
    PARAMETER_INVALID_STRING_EMPTY = "parameter_invalid_string_empty"
    PARAMETER_MISSING = "parameter_missing"
    PARAMETER_UNKNOWN = "parameter_unknown"
    PARAMETERS_EXCLUSIVE = "parameters_exclusive"
    PAYMENT_INTENT_AUTHENTICATION_FAILURE = "payment_intent_authentication_failure"
    PAYMENT_INTENT_INCOMPATIBLE_PAYMENT_METHOD = "payment_intent_incompatible_payment_method"
    PAYMENT_INTENT_INVALID_PARAMETER = "payment_intent_invalid_parameter"
    PAYMENT_INTENT_PAYMENT_ATTEMPT_FAILED = "payment_intent_payment_attempt_failed"
    PAYMENT_INTENT_UNEXPECTED_STATE = "payment_intent_unexpected_state"
    PAYMENT_METHOD_UNACTIVATED = "payment_method_unactivated"
    PAYMENT_METHOD_UNEXPECTED_STATE = "payment_method_unexpected_state"
    PAYOUTS_NOT_ALLOWED = "payouts_not_allowed"
    PLATFORM_API_KEY_EXPIRED = "platform_api_key_expired"
    POSTAL_CODE_INVALID = "postal_code_invalid"
    PROCESSING_ERROR = "processing_error"
    PRODUCT_INACTIVE = "product_inactive"
    RATE_LIMIT = "rate_limit"
    RESOURCE_ALREADY_EXISTS = "resource_already_exists"
    RESOURCE_MISSING = "resource_missing"
    ROUTING_NUMBER_INVALID = "routing_number_invalid"
    SECRET_KEY_REQUIRED = "secret_key_required"
    SEPA_UNSUPPORTED_ACCOUNT = "sepa_unsupported_account"
    SHIPPING_CALCULATION_FAILED = "shipping_calculation_failed"
    SKU_INACTIVE = "sku_inactive"
    STATE_UNSUPPORTED = "state_unsupported"
    TAX_ID_INVALID = "tax_id_invalid"
    TAXES_CALCULATION_FAILED = "taxes_calculation_failed"
    TESTMODE_CHARGES_ONLY = "testmode_charges_only"
    TLS_VERSION_UNSUPPORTED = "tls_version_unsupported"
    TOKEN_ALREADY_USED = "token_already_used"
    TOKEN_IN_USE = "token_in_use"
    TRANSFERS_NOT_ALLOWED = "transfers_not_allowed"
    UPSTREAM_ORDER_CREATION_FAILED = "upstream_order_creation_failed"
    URL_INVALID = "url_invalid"

    allowable_values = [ACCOUNT_ALREADY_EXISTS, ACCOUNT_COUNTRY_INVALID_ADDRESS, ACCOUNT_INVALID, ACCOUNT_NUMBER_INVALID, ALIPAY_UPGRADE_REQUIRED, AMOUNT_TOO_LARGE, AMOUNT_TOO_SMALL, API_KEY_EXPIRED, BALANCE_INSUFFICIENT, BANK_ACCOUNT_EXISTS, BANK_ACCOUNT_UNUSABLE, BANK_ACCOUNT_UNVERIFIED, BITCOIN_UPGRADE_REQUIRED, CARD_DECLINED, CHARGE_ALREADY_CAPTURED, CHARGE_ALREADY_REFUNDED, CHARGE_DISPUTED, CHARGE_EXCEEDS_SOURCE_LIMIT, CHARGE_EXPIRED_FOR_CAPTURE, COUNTRY_UNSUPPORTED, COUPON_EXPIRED, CUSTOMER_MAX_SUBSCRIPTIONS, EMAIL_INVALID, EXPIRED_CARD, IDEMPOTENCY_KEY_IN_USE, INCORRECT_ADDRESS, INCORRECT_CVC, INCORRECT_NUMBER, INCORRECT_ZIP, INSTANT_PAYOUTS_UNSUPPORTED, INVALID_CARD_TYPE, INVALID_CHARGE_AMOUNT, INVALID_CVC, INVALID_EXPIRY_MONTH, INVALID_EXPIRY_YEAR, INVALID_NUMBER, INVALID_SOURCE_USAGE, INVALID_SWIPE_DATA, INVOICE_NO_CUSTOMER_LINE_ITEMS, INVOICE_NO_SUBSCRIPTION_LINE_ITEMS, INVOICE_NOT_EDITABLE, INVOICE_UPCOMING_NONE, LIVEMODE_MISMATCH, MISSING, NOT_ALLOWED_ON_STANDARD_ACCOUNT, ORDER_CREATION_FAILED, ORDER_REQUIRED_SETTINGS, ORDER_STATUS_INVALID, ORDER_UPSTREAM_TIMEOUT, OUT_OF_INVENTORY, PARAMETER_INVALID_EMPTY, PARAMETER_INVALID_INTEGER, PARAMETER_INVALID_STRING_BLANK, PARAMETER_INVALID_STRING_EMPTY, PARAMETER_MISSING, PARAMETER_UNKNOWN, PARAMETERS_EXCLUSIVE, PAYMENT_INTENT_AUTHENTICATION_FAILURE, PAYMENT_INTENT_INCOMPATIBLE_PAYMENT_METHOD, PAYMENT_INTENT_INVALID_PARAMETER, PAYMENT_INTENT_PAYMENT_ATTEMPT_FAILED, PAYMENT_INTENT_UNEXPECTED_STATE, PAYMENT_METHOD_UNACTIVATED, PAYMENT_METHOD_UNEXPECTED_STATE, PAYOUTS_NOT_ALLOWED, PLATFORM_API_KEY_EXPIRED, POSTAL_CODE_INVALID, PROCESSING_ERROR, PRODUCT_INACTIVE, RATE_LIMIT, RESOURCE_ALREADY_EXISTS, RESOURCE_MISSING, ROUTING_NUMBER_INVALID, SECRET_KEY_REQUIRED, SEPA_UNSUPPORTED_ACCOUNT, SHIPPING_CALCULATION_FAILED, SKU_INACTIVE, STATE_UNSUPPORTED, TAX_ID_INVALID, TAXES_CALCULATION_FAILED, TESTMODE_CHARGES_ONLY, TLS_VERSION_UNSUPPORTED, TOKEN_ALREADY_USED, TOKEN_IN_USE, TRANSFERS_NOT_ALLOWED, UPSTREAM_ORDER_CREATION_FAILED, URL_INVALID]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """StripeApiErrorCode - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StripeApiErrorCode):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StripeApiErrorCode):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class DjStripePrice(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'djstripe_id': 'int',
        'billing_scheme': 'StripeBillingScheme',
        'human_readable_price': 'str',
        'tiers_mode': 'StripePriceTiersMode',
        'djstripe_created': 'datetime',
        'djstripe_updated': 'datetime',
        'id': 'str',
        'livemode': 'bool',
        'created': 'datetime',
        'metadata': 'dict(str, object)',
        'description': 'str',
        'active': 'bool',
        'currency': 'str',
        'nickname': 'str',
        'recurring': 'dict(str, object)',
        'type': 'StripePriceType',
        'unit_amount': 'int',
        'unit_amount_decimal': 'str',
        'lookup_key': 'str',
        'tiers': 'dict(str, object)',
        'transform_quantity': 'dict(str, object)',
        'djstripe_owner_account': 'str',
        'product': 'str'
    }

    attribute_map = {
        'djstripe_id': 'djstripe_id',
        'billing_scheme': 'billing_scheme',
        'human_readable_price': 'human_readable_price',
        'tiers_mode': 'tiers_mode',
        'djstripe_created': 'djstripe_created',
        'djstripe_updated': 'djstripe_updated',
        'id': 'id',
        'livemode': 'livemode',
        'created': 'created',
        'metadata': 'metadata',
        'description': 'description',
        'active': 'active',
        'currency': 'currency',
        'nickname': 'nickname',
        'recurring': 'recurring',
        'type': 'type',
        'unit_amount': 'unit_amount',
        'unit_amount_decimal': 'unit_amount_decimal',
        'lookup_key': 'lookup_key',
        'tiers': 'tiers',
        'transform_quantity': 'transform_quantity',
        'djstripe_owner_account': 'djstripe_owner_account',
        'product': 'product'
    }

    def __init__(self, djstripe_id=None, billing_scheme=None, human_readable_price=None, tiers_mode=None, djstripe_created=None, djstripe_updated=None, id=None, livemode=None, created=None, metadata=None, description=None, active=None, currency=None, nickname=None, recurring=None, type=None, unit_amount=None, unit_amount_decimal=None, lookup_key=None, tiers=None, transform_quantity=None, djstripe_owner_account=None, product=None, local_vars_configuration=None):  # noqa: E501
        """DjStripePrice - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._djstripe_id = None
        self._billing_scheme = None
        self._human_readable_price = None
        self._tiers_mode = None
        self._djstripe_created = None
        self._djstripe_updated = None
        self._id = None
        self._livemode = None
        self._created = None
        self._metadata = None
        self._description = None
        self._active = None
        self._currency = None
        self._nickname = None
        self._recurring = None
        self._type = None
        self._unit_amount = None
        self._unit_amount_decimal = None
        self._lookup_key = None
        self._tiers = None
        self._transform_quantity = None
        self._djstripe_owner_account = None
        self._product = None
        self.discriminator = None

        self.djstripe_id = djstripe_id
        self.billing_scheme = billing_scheme
        self.human_readable_price = human_readable_price
        self.tiers_mode = tiers_mode
        self.djstripe_created = djstripe_created
        self.djstripe_updated = djstripe_updated
        self.id = id
        self.livemode = livemode
        self.created = created
        self.metadata = metadata
        self.description = description
        self.active = active
        self.currency = currency
        if nickname is not None:
            self.nickname = nickname
        self.recurring = recurring
        self.type = type
        self.unit_amount = unit_amount
        self.unit_amount_decimal = unit_amount_decimal
        self.lookup_key = lookup_key
        self.tiers = tiers
        self.transform_quantity = transform_quantity
        self.djstripe_owner_account = djstripe_owner_account
        self.product = product

    @property
    def djstripe_id(self):
        """Gets the djstripe_id of this DjStripePrice.  # noqa: E501


        :return: The djstripe_id of this DjStripePrice.  # noqa: E501
        :rtype: int
        """
        return self._djstripe_id

    @djstripe_id.setter
    def djstripe_id(self, djstripe_id):
        """Sets the djstripe_id of this DjStripePrice.


        :param djstripe_id: The djstripe_id of this DjStripePrice.  # noqa: E501
        :type djstripe_id: int
        """
        if self.local_vars_configuration.client_side_validation and djstripe_id is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_id`, must not be `None`")  # noqa: E501

        self._djstripe_id = djstripe_id

    @property
    def billing_scheme(self):
        """Gets the billing_scheme of this DjStripePrice.  # noqa: E501


        :return: The billing_scheme of this DjStripePrice.  # noqa: E501
        :rtype: StripeBillingScheme
        """
        return self._billing_scheme

    @billing_scheme.setter
    def billing_scheme(self, billing_scheme):
        """Sets the billing_scheme of this DjStripePrice.


        :param billing_scheme: The billing_scheme of this DjStripePrice.  # noqa: E501
        :type billing_scheme: StripeBillingScheme
        """
        if self.local_vars_configuration.client_side_validation and billing_scheme is None:  # noqa: E501
            raise ValueError("Invalid value for `billing_scheme`, must not be `None`")  # noqa: E501

        self._billing_scheme = billing_scheme

    @property
    def human_readable_price(self):
        """Gets the human_readable_price of this DjStripePrice.  # noqa: E501


        :return: The human_readable_price of this DjStripePrice.  # noqa: E501
        :rtype: str
        """
        return self._human_readable_price

    @human_readable_price.setter
    def human_readable_price(self, human_readable_price):
        """Sets the human_readable_price of this DjStripePrice.


        :param human_readable_price: The human_readable_price of this DjStripePrice.  # noqa: E501
        :type human_readable_price: str
        """
        if self.local_vars_configuration.client_side_validation and human_readable_price is None:  # noqa: E501
            raise ValueError("Invalid value for `human_readable_price`, must not be `None`")  # noqa: E501

        self._human_readable_price = human_readable_price

    @property
    def tiers_mode(self):
        """Gets the tiers_mode of this DjStripePrice.  # noqa: E501


        :return: The tiers_mode of this DjStripePrice.  # noqa: E501
        :rtype: StripePriceTiersMode
        """
        return self._tiers_mode

    @tiers_mode.setter
    def tiers_mode(self, tiers_mode):
        """Sets the tiers_mode of this DjStripePrice.


        :param tiers_mode: The tiers_mode of this DjStripePrice.  # noqa: E501
        :type tiers_mode: StripePriceTiersMode
        """
        if self.local_vars_configuration.client_side_validation and tiers_mode is None:  # noqa: E501
            raise ValueError("Invalid value for `tiers_mode`, must not be `None`")  # noqa: E501

        self._tiers_mode = tiers_mode

    @property
    def djstripe_created(self):
        """Gets the djstripe_created of this DjStripePrice.  # noqa: E501


        :return: The djstripe_created of this DjStripePrice.  # noqa: E501
        :rtype: datetime
        """
        return self._djstripe_created

    @djstripe_created.setter
    def djstripe_created(self, djstripe_created):
        """Sets the djstripe_created of this DjStripePrice.


        :param djstripe_created: The djstripe_created of this DjStripePrice.  # noqa: E501
        :type djstripe_created: datetime
        """
        if self.local_vars_configuration.client_side_validation and djstripe_created is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_created`, must not be `None`")  # noqa: E501

        self._djstripe_created = djstripe_created

    @property
    def djstripe_updated(self):
        """Gets the djstripe_updated of this DjStripePrice.  # noqa: E501


        :return: The djstripe_updated of this DjStripePrice.  # noqa: E501
        :rtype: datetime
        """
        return self._djstripe_updated

    @djstripe_updated.setter
    def djstripe_updated(self, djstripe_updated):
        """Sets the djstripe_updated of this DjStripePrice.


        :param djstripe_updated: The djstripe_updated of this DjStripePrice.  # noqa: E501
        :type djstripe_updated: datetime
        """
        if self.local_vars_configuration.client_side_validation and djstripe_updated is None:  # noqa: E501
            raise ValueError("Invalid value for `djstripe_updated`, must not be `None`")  # noqa: E501

        self._djstripe_updated = djstripe_updated

    @property
    def id(self):
        """Gets the id of this DjStripePrice.  # noqa: E501


        :return: The id of this DjStripePrice.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DjStripePrice.


        :param id: The id of this DjStripePrice.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                id is not None and len(id) > 255):
            raise ValueError("Invalid value for `id`, length must be less than or equal to `255`")  # noqa: E501

        self._id = id

    @property
    def livemode(self):
        """Gets the livemode of this DjStripePrice.  # noqa: E501

        Null here indicates that the livemode status is unknown or was previously unrecorded. Otherwise, this field indicates whether this record comes from Stripe test mode or live mode operation.  # noqa: E501

        :return: The livemode of this DjStripePrice.  # noqa: E501
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """Sets the livemode of this DjStripePrice.

        Null here indicates that the livemode status is unknown or was previously unrecorded. Otherwise, this field indicates whether this record comes from Stripe test mode or live mode operation.  # noqa: E501

        :param livemode: The livemode of this DjStripePrice.  # noqa: E501
        :type livemode: bool
        """

        self._livemode = livemode

    @property
    def created(self):
        """Gets the created of this DjStripePrice.  # noqa: E501

        The datetime this object was created in stripe.  # noqa: E501

        :return: The created of this DjStripePrice.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this DjStripePrice.

        The datetime this object was created in stripe.  # noqa: E501

        :param created: The created of this DjStripePrice.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    @property
    def metadata(self):
        """Gets the metadata of this DjStripePrice.  # noqa: E501

        A set of key/value pairs that you can attach to an object. It can be useful for storing additional information about an object in a structured format.  # noqa: E501

        :return: The metadata of this DjStripePrice.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this DjStripePrice.

        A set of key/value pairs that you can attach to an object. It can be useful for storing additional information about an object in a structured format.  # noqa: E501

        :param metadata: The metadata of this DjStripePrice.  # noqa: E501
        :type metadata: dict(str, object)
        """

        self._metadata = metadata

    @property
    def description(self):
        """Gets the description of this DjStripePrice.  # noqa: E501

        A description of this object.  # noqa: E501

        :return: The description of this DjStripePrice.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DjStripePrice.

        A description of this object.  # noqa: E501

        :param description: The description of this DjStripePrice.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def active(self):
        """Gets the active of this DjStripePrice.  # noqa: E501

        Whether the price can be used for new purchases.  # noqa: E501

        :return: The active of this DjStripePrice.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this DjStripePrice.

        Whether the price can be used for new purchases.  # noqa: E501

        :param active: The active of this DjStripePrice.  # noqa: E501
        :type active: bool
        """
        if self.local_vars_configuration.client_side_validation and active is None:  # noqa: E501
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def currency(self):
        """Gets the currency of this DjStripePrice.  # noqa: E501

        Three-letter ISO currency code  # noqa: E501

        :return: The currency of this DjStripePrice.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this DjStripePrice.

        Three-letter ISO currency code  # noqa: E501

        :param currency: The currency of this DjStripePrice.  # noqa: E501
        :type currency: str
        """
        if self.local_vars_configuration.client_side_validation and currency is None:  # noqa: E501
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                currency is not None and len(currency) > 3):
            raise ValueError("Invalid value for `currency`, length must be less than or equal to `3`")  # noqa: E501

        self._currency = currency

    @property
    def nickname(self):
        """Gets the nickname of this DjStripePrice.  # noqa: E501

        A brief description of the plan, hidden from customers.  # noqa: E501

        :return: The nickname of this DjStripePrice.  # noqa: E501
        :rtype: str
        """
        return self._nickname

    @nickname.setter
    def nickname(self, nickname):
        """Sets the nickname of this DjStripePrice.

        A brief description of the plan, hidden from customers.  # noqa: E501

        :param nickname: The nickname of this DjStripePrice.  # noqa: E501
        :type nickname: str
        """
        if (self.local_vars_configuration.client_side_validation and
                nickname is not None and len(nickname) > 250):
            raise ValueError("Invalid value for `nickname`, length must be less than or equal to `250`")  # noqa: E501

        self._nickname = nickname

    @property
    def recurring(self):
        """Gets the recurring of this DjStripePrice.  # noqa: E501

        The recurring components of a price such as `interval` and `usage_type`.  # noqa: E501

        :return: The recurring of this DjStripePrice.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._recurring

    @recurring.setter
    def recurring(self, recurring):
        """Sets the recurring of this DjStripePrice.

        The recurring components of a price such as `interval` and `usage_type`.  # noqa: E501

        :param recurring: The recurring of this DjStripePrice.  # noqa: E501
        :type recurring: dict(str, object)
        """

        self._recurring = recurring

    @property
    def type(self):
        """Gets the type of this DjStripePrice.  # noqa: E501

        Whether the price is for a one-time purchase or a recurring (subscription) purchase.  # noqa: E501

        :return: The type of this DjStripePrice.  # noqa: E501
        :rtype: StripePriceType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DjStripePrice.

        Whether the price is for a one-time purchase or a recurring (subscription) purchase.  # noqa: E501

        :param type: The type of this DjStripePrice.  # noqa: E501
        :type type: StripePriceType
        """

        self._type = type

    @property
    def unit_amount(self):
        """Gets the unit_amount of this DjStripePrice.  # noqa: E501

        The unit amount in cents to be charged, represented as a whole integer if possible. Null if a sub-cent precision is required.  # noqa: E501

        :return: The unit_amount of this DjStripePrice.  # noqa: E501
        :rtype: int
        """
        return self._unit_amount

    @unit_amount.setter
    def unit_amount(self, unit_amount):
        """Sets the unit_amount of this DjStripePrice.

        The unit amount in cents to be charged, represented as a whole integer if possible. Null if a sub-cent precision is required.  # noqa: E501

        :param unit_amount: The unit_amount of this DjStripePrice.  # noqa: E501
        :type unit_amount: int
        """
        if (self.local_vars_configuration.client_side_validation and
                unit_amount is not None and unit_amount > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `unit_amount`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                unit_amount is not None and unit_amount < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `unit_amount`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._unit_amount = unit_amount

    @property
    def unit_amount_decimal(self):
        """Gets the unit_amount_decimal of this DjStripePrice.  # noqa: E501

        The unit amount in cents to be charged, represented as a decimal string with at most 12 decimal places.  # noqa: E501

        :return: The unit_amount_decimal of this DjStripePrice.  # noqa: E501
        :rtype: str
        """
        return self._unit_amount_decimal

    @unit_amount_decimal.setter
    def unit_amount_decimal(self, unit_amount_decimal):
        """Sets the unit_amount_decimal of this DjStripePrice.

        The unit amount in cents to be charged, represented as a decimal string with at most 12 decimal places.  # noqa: E501

        :param unit_amount_decimal: The unit_amount_decimal of this DjStripePrice.  # noqa: E501
        :type unit_amount_decimal: str
        """
        if (self.local_vars_configuration.client_side_validation and
                unit_amount_decimal is not None and not re.search(r'^-?\d{0,7}(?:\.\d{0,12})?$', unit_amount_decimal)):  # noqa: E501
            raise ValueError(r"Invalid value for `unit_amount_decimal`, must be a follow pattern or equal to `/^-?\d{0,7}(?:\.\d{0,12})?$/`")  # noqa: E501

        self._unit_amount_decimal = unit_amount_decimal

    @property
    def lookup_key(self):
        """Gets the lookup_key of this DjStripePrice.  # noqa: E501

        A lookup key used to retrieve prices dynamically from a static string.  # noqa: E501

        :return: The lookup_key of this DjStripePrice.  # noqa: E501
        :rtype: str
        """
        return self._lookup_key

    @lookup_key.setter
    def lookup_key(self, lookup_key):
        """Sets the lookup_key of this DjStripePrice.

        A lookup key used to retrieve prices dynamically from a static string.  # noqa: E501

        :param lookup_key: The lookup_key of this DjStripePrice.  # noqa: E501
        :type lookup_key: str
        """
        if (self.local_vars_configuration.client_side_validation and
                lookup_key is not None and len(lookup_key) > 250):
            raise ValueError("Invalid value for `lookup_key`, length must be less than or equal to `250`")  # noqa: E501

        self._lookup_key = lookup_key

    @property
    def tiers(self):
        """Gets the tiers of this DjStripePrice.  # noqa: E501

        Each element represents a pricing tier. This parameter requires `billing_scheme` to be set to `tiered`.  # noqa: E501

        :return: The tiers of this DjStripePrice.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._tiers

    @tiers.setter
    def tiers(self, tiers):
        """Sets the tiers of this DjStripePrice.

        Each element represents a pricing tier. This parameter requires `billing_scheme` to be set to `tiered`.  # noqa: E501

        :param tiers: The tiers of this DjStripePrice.  # noqa: E501
        :type tiers: dict(str, object)
        """

        self._tiers = tiers

    @property
    def transform_quantity(self):
        """Gets the transform_quantity of this DjStripePrice.  # noqa: E501

        Apply a transformation to the reported usage or set quantity before computing the amount billed. Cannot be combined with `tiers`.  # noqa: E501

        :return: The transform_quantity of this DjStripePrice.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._transform_quantity

    @transform_quantity.setter
    def transform_quantity(self, transform_quantity):
        """Sets the transform_quantity of this DjStripePrice.

        Apply a transformation to the reported usage or set quantity before computing the amount billed. Cannot be combined with `tiers`.  # noqa: E501

        :param transform_quantity: The transform_quantity of this DjStripePrice.  # noqa: E501
        :type transform_quantity: dict(str, object)
        """

        self._transform_quantity = transform_quantity

    @property
    def djstripe_owner_account(self):
        """Gets the djstripe_owner_account of this DjStripePrice.  # noqa: E501

        The Stripe Account this object belongs to.  # noqa: E501

        :return: The djstripe_owner_account of this DjStripePrice.  # noqa: E501
        :rtype: str
        """
        return self._djstripe_owner_account

    @djstripe_owner_account.setter
    def djstripe_owner_account(self, djstripe_owner_account):
        """Sets the djstripe_owner_account of this DjStripePrice.

        The Stripe Account this object belongs to.  # noqa: E501

        :param djstripe_owner_account: The djstripe_owner_account of this DjStripePrice.  # noqa: E501
        :type djstripe_owner_account: str
        """

        self._djstripe_owner_account = djstripe_owner_account

    @property
    def product(self):
        """Gets the product of this DjStripePrice.  # noqa: E501

        The product this price is associated with.  # noqa: E501

        :return: The product of this DjStripePrice.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this DjStripePrice.

        The product this price is associated with.  # noqa: E501

        :param product: The product of this DjStripePrice.  # noqa: E501
        :type product: str
        """
        if self.local_vars_configuration.client_side_validation and product is None:  # noqa: E501
            raise ValueError("Invalid value for `product`, must not be `None`")  # noqa: E501

        self._product = product

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DjStripePrice):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DjStripePrice):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class Pi(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'last_boot': 'str',
        'settings': 'PiSettings',
        'user': 'User',
        'system_info': 'SystemInfo',
        'webrtc_edge': 'WebrtcStream',
        'webrtc_cloud': 'WebrtcStream',
        'octoprint_server': 'OctoPrintServer',
        'urls': 'PiUrls',
        'nats_app': 'PiNatsApp',
        'sbc': 'SbcEnum',
        'created_dt': 'datetime',
        'hostname': 'str',
        'fqdn': 'str',
        'favorite': 'bool',
        'setup_finished': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'last_boot': 'last_boot',
        'settings': 'settings',
        'user': 'user',
        'system_info': 'system_info',
        'webrtc_edge': 'webrtc_edge',
        'webrtc_cloud': 'webrtc_cloud',
        'octoprint_server': 'octoprint_server',
        'urls': 'urls',
        'nats_app': 'nats_app',
        'sbc': 'sbc',
        'created_dt': 'created_dt',
        'hostname': 'hostname',
        'fqdn': 'fqdn',
        'favorite': 'favorite',
        'setup_finished': 'setup_finished'
    }

    def __init__(self, id=None, last_boot=None, settings=None, user=None, system_info=None, webrtc_edge=None, webrtc_cloud=None, octoprint_server=None, urls=None, nats_app=None, sbc=None, created_dt=None, hostname=None, fqdn=None, favorite=None, setup_finished=None, local_vars_configuration=None):  # noqa: E501
        """Pi - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._last_boot = None
        self._settings = None
        self._user = None
        self._system_info = None
        self._webrtc_edge = None
        self._webrtc_cloud = None
        self._octoprint_server = None
        self._urls = None
        self._nats_app = None
        self._sbc = None
        self._created_dt = None
        self._hostname = None
        self._fqdn = None
        self._favorite = None
        self._setup_finished = None
        self.discriminator = None

        self.id = id
        self.last_boot = last_boot
        self.settings = settings
        self.user = user
        self.system_info = system_info
        self.webrtc_edge = webrtc_edge
        self.webrtc_cloud = webrtc_cloud
        self.octoprint_server = octoprint_server
        self.urls = urls
        self.nats_app = nats_app
        if sbc is not None:
            self.sbc = sbc
        self.created_dt = created_dt
        if hostname is not None:
            self.hostname = hostname
        if fqdn is not None:
            self.fqdn = fqdn
        if favorite is not None:
            self.favorite = favorite
        if setup_finished is not None:
            self.setup_finished = setup_finished

    @property
    def id(self):
        """Gets the id of this Pi.  # noqa: E501


        :return: The id of this Pi.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Pi.


        :param id: The id of this Pi.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def last_boot(self):
        """Gets the last_boot of this Pi.  # noqa: E501


        :return: The last_boot of this Pi.  # noqa: E501
        :rtype: str
        """
        return self._last_boot

    @last_boot.setter
    def last_boot(self, last_boot):
        """Sets the last_boot of this Pi.


        :param last_boot: The last_boot of this Pi.  # noqa: E501
        :type last_boot: str
        """

        self._last_boot = last_boot

    @property
    def settings(self):
        """Gets the settings of this Pi.  # noqa: E501


        :return: The settings of this Pi.  # noqa: E501
        :rtype: PiSettings
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this Pi.


        :param settings: The settings of this Pi.  # noqa: E501
        :type settings: PiSettings
        """

        self._settings = settings

    @property
    def user(self):
        """Gets the user of this Pi.  # noqa: E501


        :return: The user of this Pi.  # noqa: E501
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Pi.


        :param user: The user of this Pi.  # noqa: E501
        :type user: User
        """

        self._user = user

    @property
    def system_info(self):
        """Gets the system_info of this Pi.  # noqa: E501


        :return: The system_info of this Pi.  # noqa: E501
        :rtype: SystemInfo
        """
        return self._system_info

    @system_info.setter
    def system_info(self, system_info):
        """Sets the system_info of this Pi.


        :param system_info: The system_info of this Pi.  # noqa: E501
        :type system_info: SystemInfo
        """

        self._system_info = system_info

    @property
    def webrtc_edge(self):
        """Gets the webrtc_edge of this Pi.  # noqa: E501


        :return: The webrtc_edge of this Pi.  # noqa: E501
        :rtype: WebrtcStream
        """
        return self._webrtc_edge

    @webrtc_edge.setter
    def webrtc_edge(self, webrtc_edge):
        """Sets the webrtc_edge of this Pi.


        :param webrtc_edge: The webrtc_edge of this Pi.  # noqa: E501
        :type webrtc_edge: WebrtcStream
        """

        self._webrtc_edge = webrtc_edge

    @property
    def webrtc_cloud(self):
        """Gets the webrtc_cloud of this Pi.  # noqa: E501


        :return: The webrtc_cloud of this Pi.  # noqa: E501
        :rtype: WebrtcStream
        """
        return self._webrtc_cloud

    @webrtc_cloud.setter
    def webrtc_cloud(self, webrtc_cloud):
        """Sets the webrtc_cloud of this Pi.


        :param webrtc_cloud: The webrtc_cloud of this Pi.  # noqa: E501
        :type webrtc_cloud: WebrtcStream
        """

        self._webrtc_cloud = webrtc_cloud

    @property
    def octoprint_server(self):
        """Gets the octoprint_server of this Pi.  # noqa: E501


        :return: The octoprint_server of this Pi.  # noqa: E501
        :rtype: OctoPrintServer
        """
        return self._octoprint_server

    @octoprint_server.setter
    def octoprint_server(self, octoprint_server):
        """Sets the octoprint_server of this Pi.


        :param octoprint_server: The octoprint_server of this Pi.  # noqa: E501
        :type octoprint_server: OctoPrintServer
        """

        self._octoprint_server = octoprint_server

    @property
    def urls(self):
        """Gets the urls of this Pi.  # noqa: E501


        :return: The urls of this Pi.  # noqa: E501
        :rtype: PiUrls
        """
        return self._urls

    @urls.setter
    def urls(self, urls):
        """Sets the urls of this Pi.


        :param urls: The urls of this Pi.  # noqa: E501
        :type urls: PiUrls
        """
        if self.local_vars_configuration.client_side_validation and urls is None:  # noqa: E501
            raise ValueError("Invalid value for `urls`, must not be `None`")  # noqa: E501

        self._urls = urls

    @property
    def nats_app(self):
        """Gets the nats_app of this Pi.  # noqa: E501


        :return: The nats_app of this Pi.  # noqa: E501
        :rtype: PiNatsApp
        """
        return self._nats_app

    @nats_app.setter
    def nats_app(self, nats_app):
        """Sets the nats_app of this Pi.


        :param nats_app: The nats_app of this Pi.  # noqa: E501
        :type nats_app: PiNatsApp
        """

        self._nats_app = nats_app

    @property
    def sbc(self):
        """Gets the sbc of this Pi.  # noqa: E501


        :return: The sbc of this Pi.  # noqa: E501
        :rtype: SbcEnum
        """
        return self._sbc

    @sbc.setter
    def sbc(self, sbc):
        """Sets the sbc of this Pi.


        :param sbc: The sbc of this Pi.  # noqa: E501
        :type sbc: SbcEnum
        """

        self._sbc = sbc

    @property
    def created_dt(self):
        """Gets the created_dt of this Pi.  # noqa: E501


        :return: The created_dt of this Pi.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this Pi.


        :param created_dt: The created_dt of this Pi.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def hostname(self):
        """Gets the hostname of this Pi.  # noqa: E501

        Please enter the hostname you set in the Raspberry Pi Imager's Advanced Options menu (without .local extension)  # noqa: E501

        :return: The hostname of this Pi.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this Pi.

        Please enter the hostname you set in the Raspberry Pi Imager's Advanced Options menu (without .local extension)  # noqa: E501

        :param hostname: The hostname of this Pi.  # noqa: E501
        :type hostname: str
        """
        if (self.local_vars_configuration.client_side_validation and
                hostname is not None and len(hostname) > 255):
            raise ValueError("Invalid value for `hostname`, length must be less than or equal to `255`")  # noqa: E501

        self._hostname = hostname

    @property
    def fqdn(self):
        """Gets the fqdn of this Pi.  # noqa: E501


        :return: The fqdn of this Pi.  # noqa: E501
        :rtype: str
        """
        return self._fqdn

    @fqdn.setter
    def fqdn(self, fqdn):
        """Sets the fqdn of this Pi.


        :param fqdn: The fqdn of this Pi.  # noqa: E501
        :type fqdn: str
        """
        if (self.local_vars_configuration.client_side_validation and
                fqdn is not None and len(fqdn) > 255):
            raise ValueError("Invalid value for `fqdn`, length must be less than or equal to `255`")  # noqa: E501

        self._fqdn = fqdn

    @property
    def favorite(self):
        """Gets the favorite of this Pi.  # noqa: E501


        :return: The favorite of this Pi.  # noqa: E501
        :rtype: bool
        """
        return self._favorite

    @favorite.setter
    def favorite(self, favorite):
        """Sets the favorite of this Pi.


        :param favorite: The favorite of this Pi.  # noqa: E501
        :type favorite: bool
        """

        self._favorite = favorite

    @property
    def setup_finished(self):
        """Gets the setup_finished of this Pi.  # noqa: E501


        :return: The setup_finished of this Pi.  # noqa: E501
        :rtype: bool
        """
        return self._setup_finished

    @setup_finished.setter
    def setup_finished(self, setup_finished):
        """Sets the setup_finished of this Pi.


        :param setup_finished: The setup_finished of this Pi.  # noqa: E501
        :type setup_finished: bool
        """

        self._setup_finished = setup_finished

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pi):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Pi):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.devices_api import DevicesApi  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestDevicesApi(unittest.TestCase):
    """DevicesApi unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.devices_api.DevicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_pi_update_or_create(self):
        """Test case for pi_update_or_create

        """
        pass

    def test_pis_create(self):
        """Test case for pis_create

        """
        pass

    def test_pis_destroy(self):
        """Test case for pis_destroy

        """
        pass

    def test_pis_license_cloud_api_retrieve(self):
        """Test case for pis_license_cloud_api_retrieve

        """
        pass

    def test_pis_license_zip_retrieve(self):
        """Test case for pis_license_zip_retrieve

        """
        pass

    def test_pis_list(self):
        """Test case for pis_list

        """
        pass

    def test_pis_partial_update(self):
        """Test case for pis_partial_update

        """
        pass

    def test_pis_retrieve(self):
        """Test case for pis_retrieve

        """
        pass

    def test_pis_settings_create(self):
        """Test case for pis_settings_create

        """
        pass

    def test_pis_settings_list(self):
        """Test case for pis_settings_list

        """
        pass

    def test_pis_settings_partial_update(self):
        """Test case for pis_settings_partial_update

        """
        pass

    def test_pis_settings_retrieve(self):
        """Test case for pis_settings_retrieve

        """
        pass

    def test_pis_settings_update(self):
        """Test case for pis_settings_update

        """
        pass

    def test_pis_system_info_create(self):
        """Test case for pis_system_info_create

        """
        pass

    def test_pis_system_info_list(self):
        """Test case for pis_system_info_list

        """
        pass

    def test_pis_system_info_partial_update(self):
        """Test case for pis_system_info_partial_update

        """
        pass

    def test_pis_system_info_retrieve(self):
        """Test case for pis_system_info_retrieve

        """
        pass

    def test_pis_system_info_update(self):
        """Test case for pis_system_info_update

        """
        pass

    def test_pis_update(self):
        """Test case for pis_update

        """
        pass

    def test_pis_webrtc_streams_create(self):
        """Test case for pis_webrtc_streams_create

        """
        pass

    def test_pis_webrtc_streams_list(self):
        """Test case for pis_webrtc_streams_list

        """
        pass

    def test_pis_webrtc_streams_partial_update(self):
        """Test case for pis_webrtc_streams_partial_update

        """
        pass

    def test_pis_webrtc_streams_retrieve(self):
        """Test case for pis_webrtc_streams_retrieve

        """
        pass

    def test_pis_webrtc_streams_update(self):
        """Test case for pis_webrtc_streams_update

        """
        pass

    def test_system_info_update_or_create(self):
        """Test case for system_info_update_or_create

        """
        pass

    def test_webrtc_stream_update_or_create(self):
        """Test case for webrtc_stream_update_or_create

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for printnanny.ai  # noqa: E501

    The version of the OpenAPI document: 0.110.0
    Contact: leigh@printnanny.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.pi_nats_app import PiNatsApp  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPiNatsApp(unittest.TestCase):
    """PiNatsApp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PiNatsApp
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.pi_nats_app.PiNatsApp()  # noqa: E501
        if include_optional :
            return PiNatsApp(
                id = 56, 
                app_name = '', 
                json = {
                    'key' : null
                    }, 
                pi = 56, 
                organization = printnanny_api_client.models.nats_organization.NatsOrganization(
                    id = 56, 
                    name = '', 
                    is_active = True, 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    slug = 'z', 
                    json = {
                        'key' : null
                        }, 
                    imports = [
                        56
                        ], 
                    exports = [
                        56
                        ], 
                    users = [
                        56
                        ], ), 
                organization_user = 56, 
                nats_server_uri = '', 
                nats_ws_uri = '', 
                nats_subject_pattern = '', 
                nats_subject_pattern_template = ''
            )
        else :
            return PiNatsApp(
                id = 56,
                pi = 56,
                organization = printnanny_api_client.models.nats_organization.NatsOrganization(
                    id = 56, 
                    name = '', 
                    is_active = True, 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    slug = 'z', 
                    json = {
                        'key' : null
                        }, 
                    imports = [
                        56
                        ], 
                    exports = [
                        56
                        ], 
                    users = [
                        56
                        ], ),
                organization_user = 56,
                nats_server_uri = '',
                nats_ws_uri = '',
                nats_subject_pattern = '',
                nats_subject_pattern_template = '',
        )

    def testPiNatsApp(self):
        """Test PiNatsApp"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
